@@ -3,8 +3,6 @@ package Exception::BaseTest;
 use strict;
 use warnings;
 
-use utf8;
-
 use Test::Unit::Lite;
 use base 'Test::Unit::TestCase';
 
@@ -572,6 +570,7 @@ sub test_overload {
 
     # smart matching for Perl 5.10
     if ($] >= 5.010) {
+        no if $] >= 5.018, warnings => 'experimental::smartmatch';
         eval q{
             $self->assert_num_equals(1, 'String' ~~ $obj);
         };
