@@ -2,9 +2,12 @@
 
 use lib 'lib', '../lib';
 
-BEGIN {
+{
     package My::Common;
-    *throw_something = $0 =~ /_ok/ ? sub () { 0 } : sub () { 1 };
+    sub throw_something {
+        return '' if $0 =~ /_ok/;
+        return 1;
+    };
 };
 
 {
@@ -15,6 +18,13 @@ BEGIN {
     };
 };
 
+{
+    package My::Try;
+    sub try ($) {
+        eval { $_[0]->() };
+    };
+};
+
 use Exception::Base 'Exception::My';
 
 
@@ -183,9 +193,34 @@ eval q{
     };
 };
 
+BEGIN {
+    eval q{
+        package My::TryTiny;
+        use Try::Tiny;
+    };
+};
+eval q{
+    package My::TryTiny;
+
+    Try::Tiny->VERSION or die;
+
+    $main::tests{'10_TryTiny'} = sub {
+
+        try {
+            die 'Message' if My::Common::throw_something;
+        }
+        catch {
+            if ($@ =~ /^Message/) {
+                1;
+            };
+        };
+
+    };
+};
+
 
 use Benchmark ':all';
 
-print "Benchmark for ", (My::Common::throw_something ? "FAIL" : "OK"), "\n";
+print "Benchmark for ", (My::Common::throw_something() ? "FAIL" : "OK"), "\n";
 my $result = timethese($ARGV[0] || -1, { %tests });
 cmpthese($result);
